From 8574e9159b5b5810a250e40404c51413586fe79a Mon Sep 17 00:00:00 2001
From: Chris Hanson <org/chris-hanson/cph>
Date: Sat, 12 May 2018 22:30:12 -0700
Subject: [PATCH] Change "unparser" to "printer" in number printer.

---
 src/runtime/dragon4.scm | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/src/runtime/dragon4.scm b/src/runtime/dragon4.scm
index 8667bb51a..8691c8903 100644
--- a/src/runtime/dragon4.scm
+++ b/src/runtime/dragon4.scm
@@ -24,7 +24,7 @@ USA.
 
 |#
 
 ;;;; Floating Point Number Unparser
 ;;; package: (runtime number)
 
 #|
@@ -159,8 +159,7 @@ not much different to numbers within a few orders of magnitude of 1.
 		       (lookup-symbolic-display-mode
 			(caddr cutoff)))))
 	  (else
-	   (warn "illegal flonum unparser cutoff parameter"
-		 cutoff)
+	   (warn "illegal flonum printer cutoff parameter" cutoff)
 	   (values 'normal 0 flonum-printer:normal-output)))))
 
 (define (cutoff-spec? cutoff)
@@ -184,7 +183,7 @@ not much different to numbers within a few orders of magnitude of 1.
 		      (and (procedure? mode)
 			   (procedure-arity-valid? mode 3))))))))
 
-(define-guarantee cutoff-spec "flonum unparser cutoff spec")
+(define-guarantee cutoff-spec "flonum printer cutoff spec")
 
 (define (lookup-symbolic-display-mode mode)
   (case mode
@@ -24,7 +24,7 @@ USA.
 |#
 
-;;;; Floating Point Number Unparser
+;;;; Floating point number printer
 ;;; package: (runtime number)
 
-- 
2.25.1